@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-# (C) British Crown Copyright 2006-16 Met Office.
+# (C) British Crown Copyright 2006-17 Met Office.
 #
 # This file is part of FCM, tools for managing and building source code.
 #
@@ -1794,7 +1794,9 @@ sub _cm_get_source {
         return _cm_err(FCM1::Cm::Exception->INVALID_BRANCH, $source_url);
     }
     $source->url_peg(
-      $source->branch_url() . '/' . $target->subdir() . '@' . $source->pegrev()
+        $source->branch_url()
+        . ($target->subdir() ? '/' . $target->subdir() : q{})
+        . ('@' . $source->pegrev())
     );
     # Ensure that the source and target URLs are in the same project
     if ($source->project_url() ne $target->project_url()) {
